@@ -330,6 +330,7 @@ class _MainUI():
                 self.mainui.entryframe.uuid_entry.delete(0, END)
                 self.mainui.entryframe.uuid_entry['state'] = 'disabled'
                 self.mainui.entryframe.name_entry.delete(0, END)
+                self.mainui.entryframe.gender_entry.delete(0 , END)
                 self.mainui.entryframe.DOB_entry.delete(0, END)
                 self.mainui.entryframe.address_entry.delete(0, END)
                 self.mainui.entryframe.note_text.delete('1.0', END)
@@ -418,16 +419,13 @@ class _MainUI():
 
             if len(label_value+  value_v+ note_value )< 1: continue
             
-            if PersonInfo.exists(person_id =p.id, label =label_value):
-                p_i = select( _p_i for _p_i in PersonInfo \
-                    if _p_i.person_id == p.id and _p_i.label == label_value)\
-                    .first()
-
+            p_i = PersonInfo.get(person_id =p.id, label =label_value)
+            if p_i:
                 if debug: print( 'PersonInfo exists' )
                 p_i.value = value_v;    p_i.note = note_value
             else:
                 if debug: print( 'New PersonInfo' )
-                PersonInfo( id = frame_name,
+                p_i = PersonInfo( id = frame_name,
                     note = note_value,      person_id = p.id,      
                     label = label_value,    value = value_v
                 )
